﻿Imports PdfSharp
Imports PdfSharp.Drawing
Imports PdfSharp.Pdf
Imports System.IO
Imports MigraDoc.DocumentObjectModel
Imports MigraDoc.DocumentObjectModel.Tables
Imports MigraDoc.Rendering

Public Class Form1

    Private Sub btnGerarPDF_Click(sender As Object, e As EventArgs) Handles btnGerarPDF.Click

        Try
            If Not String.IsNullOrEmpty(txtTexto.Text) And Not String.IsNullOrEmpty(txtDestino.Text) Then
                If File.Exists(txtDestino.Text) Then
                    'Cria um documento PDF
                    Dim pdf As PdfDocument = New PdfDocument

                    'definindo informações do autor e palavras chaves
                    pdf.Info.Author = "Macoratti"
                    pdf.Info.Keywords = "PdfSharp, Exemplos, VB .NET"
                    'informando a data de criação do documento
                    pdf.Info.CreationDate = DateTime.Now
                    ' informando o assunto
                    pdf.Info.Subject = "Gerando PDF com PDFSharp no VB .NET"

                    'cria uma página vazia
                    Dim pdfPage As PdfPage = pdf.AddPage
                    'define o tamanho da página
                    pdfPage.Size = PageSize.A4

                    'Cria um objeto XGraphics
                    Dim graph As XGraphics = XGraphics.FromPdfPage(pdfPage)

                    ' Desenha linhas
                    Dim pen As XPen = New XPen(XColor.FromArgb(255, 0, 0))
                    graph.DrawLine(pen, New XPoint(0, 0), New XPoint(pdfPage.Width.Point, pdfPage.Height.Point))
                    graph.DrawLine(pen, New XPoint(pdfPage.Width.Point, 0), New XPoint(0, pdfPage.Height.Point))

                    'Desenha uma elipse
                    graph.DrawEllipse(pen, 3 * pdfPage.Width.Point / 10, 3 * pdfPage.Height.Point / 10, 2 * pdfPage.Width.Point / 5, 2 * pdfPage.Height.Point / 5)

                    'Cria um objeto Font a partir de XFont
                    Dim font As XFont = New XFont("Verdana", 15, XFontStyle.Bold)

                    'Incluir um  conteúdo no seu documento PDF
                    graph.DrawString(txtTexto.Text, font, XBrushes.Black, New XRect(0, 0, pdfPage.Width.Point, pdfPage.Height.Point), XStringFormats.TopLeft)

                    'XStringFormats.Center will place the your content to the center of the PDF page.

                    'Salva o documento PDF
                    pdf.Save(txtDestino.Text)
                    MessageBox.Show("Arquivo   [" + txtDestino.Text + "]   gerado com sucesso.", "Alerta", MessageBoxButtons.OK, MessageBoxIcon.Information)

                    'abre o arquivo PDF e exibe 
                    Process.Start(txtDestino.Text)
                Else
                    MessageBox.Show("O arquivo/diretório de destino não existe...", "Alerta", MessageBoxButtons.OK, MessageBoxIcon.Information)
                End If
            Else
                MessageBox.Show("Informe o arquivo de destino e/ou o texto do arquivo PDF...", "Alerta", MessageBoxButtons.OK, MessageBoxIcon.Information)
            End If
        Catch ex As Exception
            'captura erros
            MessageBox.Show("Erro : " + ex.Message, "Erro", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

    End Sub

    Private Sub btnGerarPDFMigradoc_Click(sender As Object, e As EventArgs) Handles btnGerarPDFMigradoc.Click

        Try
            Dim pdf As Document = New Document

            'definindo informações do autor e palavras chaves
            pdf.Info.Author = "Macoratti"
            pdf.Info.Keywords = "PdfSharp, Exemplos, VB .NET"
            ' informando o assunto
            pdf.Info.Subject = "Gerando PDF com PDFSharp no VB .NET"

            ' Define o tamanho da pagina
            Dim width, height As Unit
            PageSetup.GetPageSize(PageFormat.A4, width, height)

            ' Adiciona uma seção ao documenteo e configura para que 
            ' ele esteja no centro na pagina
            Dim section As Section = pdf.AddSection

            section.PageSetup.PageHeight = height
            section.PageSetup.PageWidth = width
            section.PageSetup.LeftMargin = 0
            section.PageSetup.RightMargin = 0

            ' Cria uma tabela de forma que possamos desenhar linhas horizontais
            Dim table As Table = New Table

            table.Borders.Width = 1  ' Valor padrão para exibir bordas 
            Dim column As Column = New Column
            column = table.AddColumn(width)
            column.Format.Alignment = ParagraphAlignment.Center

            Dim fontHeight As Double = 36
            Dim font As Font = New Font("Times New Roman", fontHeight)

            ' Adiciona uma linha com uma unica celula para a primeira linha
            Dim row As Row = table.AddRow()
            Dim cell As Cell = row.Cells(0)

            'define o formato e as bordas
            cell.Format.Font.Color = Colors.Black
            cell.Format.Font.ApplyFont(font)
            cell.Borders.Left.Visible = False
            cell.Borders.Right.Visible = False
            cell.Borders.Bottom.Visible = False

            cell.AddParagraph("http://www.macoratti.net")

            ' Adiciona uma linha com uma unica celula para a segunda linha
            row = table.AddRow()
            cell = row.Cells(0)

            'define o formato e as bordas
            cell.Format.Font.Color = Colors.Black
            cell.Format.Alignment = ParagraphAlignment.Left
            cell.Format.Font.ApplyFont(font)
            cell.Borders.Left.Visible = False
            cell.Borders.Right.Visible = False
            cell.Borders.Top.Visible = False

            'adiciona o paragráfo ao documento
            cell.AddParagraph(txtTexto.Text)
            'adiciona na tabela
            pdf.LastSection.Add(table)

            ' Cria um renderizados
            Dim pdfRenderer As PdfDocumentRenderer = New PdfDocumentRenderer

            'Associa o documento MigraDoc com o renderizador
            pdfRenderer.Document = pdf

            'Layout e renderiza o documento PDF
            pdfRenderer.RenderDocument()

            'Salva e exibe o documento PDF
            pdfRenderer.PdfDocument.Save(txtDestino.Text)
            Process.Start(txtDestino.Text)
        Catch ex As Exception
            'captura erros
            MessageBox.Show("Erro : " + ex.Message, "Erro", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub
End Class
